@@ -14,7 +14,6 @@
 import argparse
 import os
 import simplejson
-import sys
 import textwrap
 
 
@@ -63,7 +62,6 @@ def main(stdout=None):
     args = parse_args()
     environment._configure_logging(args)
 
-    sys.stderr.write(args.services)
     if os.path.isfile(args.services):
         with open(args.services, 'r') as service_file:
             services = simplejson.load(service_file)
